@@ -14,9 +14,7 @@
 #ifndef _UAPI_LINUX_CAPABILITY_H
 #define _UAPI_LINUX_CAPABILITY_H
 
-#include <stdint.h>
-#define __u32 uint32_t
-#define __le32 __u32
+#include <linux/types.h>
 
 /* User-level do most of the mapping between kernel and user
    capabilities based on the version tag given by the kernel. The
@@ -41,13 +39,13 @@
 typedef struct __user_cap_header_struct {
 	__u32 version;
 	int pid;
-} *cap_user_header_t;
+} __user *cap_user_header_t;
 
 typedef struct __user_cap_data_struct {
         __u32 effective;
         __u32 permitted;
         __u32 inheritable;
-} *cap_user_data_t;
+} __user *cap_user_data_t;
 
 
 #define VFS_CAP_REVISION_MASK	0xFF000000
@@ -333,8 +331,6 @@ struct vfs_ns_cap_data {
 
 #define CAP_AUDIT_CONTROL    30
 
-/* Set capabilities on files. */
-
 #define CAP_SETFCAP	     31
 
 /* Override MAC access.
@@ -370,50 +366,8 @@ struct vfs_ns_cap_data {
 
 #define CAP_AUDIT_READ       37
 
-/* Allow system performance and observability privileged operations using
- * perf_events, i915_perf and other kernel subsystems. */
 
-#define CAP_PERFMON	     38
-
-/*
- * CAP_BPF allows the following BPF operations:
- * - Creating all types of BPF maps
- * - Advanced verifier features
- *   - Indirect variable access
- *   - Bounded loops
- *   - BPF to BPF function calls
- *   - Scalar precision tracking
- *   - Larger complexity limits
- *   - Dead code elimination
- *   - And potentially other features
- * - Loading BPF Type Format (BTF) data
- * - Retrieve xlated and JITed code of BPF programs
- * - Use bpf_spin_lock() helper
- *
- * CAP_PERFMON relaxes the verifier checks further:
- * - BPF progs can use of pointer-to-integer conversions
- * - speculation attack hardening measures are bypassed
- * - bpf_probe_read to read arbitrary kernel memory is allowed
- * - bpf_trace_printk to print kernel memory is allowed
- *
- * CAP_SYS_ADMIN is required to use bpf_probe_write_user.
- *
- * CAP_SYS_ADMIN is required to iterate system wide loaded
- * programs, maps, links, BTFs and convert their IDs to file descriptors.
- *
- * CAP_PERFMON and CAP_BPF are required to load tracing programs.
- * CAP_NET_ADMIN and CAP_BPF are required to load networking programs.
- */
-
-#define CAP_BPF		     39
-
-/* Allow checkpoint/restore related operations */
-/* Allow PID selection during clone3() */
-/* Allow writing to ns_last_pid */
-
-#define CAP_CHECKPOINT_RESTORE 40
-
-#define CAP_LAST_CAP         CAP_CHECKPOINT_RESTORE
+#define CAP_LAST_CAP         CAP_AUDIT_READ
 
 #define cap_valid(x) ((x) >= 0 && (x) <= CAP_LAST_CAP)
 
@@ -422,6 +376,7 @@ struct vfs_ns_cap_data {
  */
 
 #define CAP_TO_INDEX(x)     ((x) >> 5)        /* 1 << 5 == bits in __u32 */
-#define CAP_TO_MASK(x)      (1u << ((x) & 31)) /* mask for indexed __u32 */
+#define CAP_TO_MASK(x)      (1 << ((x) & 31)) /* mask for indexed __u32 */
+
 
 #endif /* _UAPI_LINUX_CAPABILITY_H */
